import { Switch, Route, useLocation } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { useEffect, lazy, Suspense } from "react";
import { LanguageProvider } from "@/contexts/language-context";

import NewsletterPopup from "@/components/newsletter-popup";
import LazyLoader from "@/components/lazy-loader";
import CookieConsentImmediate from "@/components/cookie-consent-immediate";
import SchemaMarkup from "@/components/schema-markup";
import DynamicMeta from "@/components/dynamic-meta";

// Critical pages loaded immediately
import Home from "@/pages/home";
import ContactPage from "@/pages/contact";
import NotFound from "@/pages/not-found";

// Non-critical pages lazy loaded
const ServicesPage = lazy(() => import("@/pages/services"));
const ProjectsPage = lazy(() => import("@/pages/projects"));
const AboutPage = lazy(() => import("@/pages/about"));
const NewsPage = lazy(() => import("@/pages/news"));
const NewsArticlePage = lazy(() => import("@/pages/news-article"));
const AIIntegrationPage = lazy(() => import("@/pages/services/ai-integration"));
const AutomationPage = lazy(() => import("@/pages/services/automation"));
const AIConsultingPage = lazy(() => import("@/pages/services/ai-consulting"));
const AITrainingPage = lazy(() => import("@/pages/services/ai-training"));
const AIVoiceAgentProject = lazy(() => import("@/pages/projects/ai-voice-agent"));
const ChatbotSupportProject = lazy(() => import("@/pages/projects/chatbot-support"));
const AutomationSupportProject = lazy(() => import("@/pages/projects/automation-support"));
const DemoPage = lazy(() => import("@/pages/demo"));
const PrivacyPolicyPage = lazy(() => import("@/pages/privacy-policy"));
const TermsConditionsPage = lazy(() => import("@/pages/terms-conditions"));
const AIReadinessPage = lazy(() => import("@/pages/ai-readiness"));
const AdminPage = lazy(() => import("@/pages/admin"));

function ScrollToTop() {
  const [location] = useLocation();

  useEffect(() => {
    // Cross-browser scroll to top with fallbacks for Firefox
    try {
      window.scrollTo({
        top: 0,
        left: 0,
        behavior: 'instant'
      });
    } catch (error) {
      // Fallback for older browsers or Firefox issues
      document.documentElement.scrollTop = 0;
      document.body.scrollTop = 0;
    }
  }, [location]);

  return null;
}

function Router() {
  return (
    <>
      <ScrollToTop />
      <Suspense fallback={
        <div className="min-h-screen flex items-center justify-center">
          <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-purple-600"></div>
        </div>
      }>
        <Switch>
          <Route path="/" component={Home} />
          <Route path="/services" component={ServicesPage} />
          <Route path="/services/ai-integration" component={AIIntegrationPage} />
          <Route path="/services/automation" component={AutomationPage} />
          <Route path="/services/ai-consulting" component={AIConsultingPage} />
          <Route path="/services/ai-training" component={AITrainingPage} />  
          <Route path="/projects" component={ProjectsPage} />
          <Route path="/projects/ai-voice-agent" component={AIVoiceAgentProject} />
          <Route path="/projects/chatbot-support" component={ChatbotSupportProject} />
          <Route path="/projects/automation-support" component={AutomationSupportProject} />
          <Route path="/demo" component={DemoPage} />
          <Route path="/ai-readiness" component={AIReadinessPage} />
          <Route path="/about" component={AboutPage} />
          <Route path="/contact" component={ContactPage} />
          <Route path="/privacy-policy" component={PrivacyPolicyPage} />
          <Route path="/terms" component={TermsConditionsPage} />
          <Route path="/news" component={NewsPage} />
          <Route path="/news/:slug" component={NewsArticlePage} />
          <Route path="/admin" component={AdminPage} />
          
          <Route component={NotFound} />
        </Switch>
      </Suspense>
    </>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <TooltipProvider>
        <LanguageProvider>
          <DynamicMeta />
          <Toaster />
          <Router />

          <SchemaMarkup />
          <NewsletterPopup />
          <CookieConsentImmediate />
        </LanguageProvider>
      </TooltipProvider>
    </QueryClientProvider>
  );
}

export default App;
